//
// Patron pour la generation d'une classe derivee dans ROOT
// FDevice derive de TNamed
//

#ifndef FDevice_h
#define FDevice_h

#include "TNamed.h"
#include "TClass.h"
#include "TGFrame.h"
#include "TEnv.h"

class FDevice : public TNamed {

   protected:
	TGCompositeFrame *deviceGUI;
	TString		 guiName;
	Bool_t		 changed;

   protected:
        virtual void Init(void);       // initialisation
        virtual void InitGUI(void);       // initialisation du GUI

   public:
   	FDevice(void);    // constructeur par defaut
	FDevice(const FDevice &ap); // constructeur par copie

	~FDevice(void);		// desctructeur;

#if ROOT_VERSION_CODE >= ROOT_VERSION(3,4,0)
   	virtual void Copy(TObject & obj) const;
#else
   	virtual void Copy(TObject & obj);
#endif
	FDevice& operator = (const FDevice &hp); // operateur =

	virtual void Open(void)=0;
	virtual void Close(void)=0;
	virtual void Rewind(void)=0;
	virtual void RewindAt(Int_t pos) {;}
	virtual UChar_t *GetBuffer(Int_t &size)=0;
	virtual Bool_t IsOk(void) {return kTRUE;}
	virtual Bool_t IsOpen(void) {return kTRUE;}
	virtual Bool_t IsClosed(void) {return kFALSE;}
	virtual void SetChanged(void) {changed=kTRUE;}
	virtual Bool_t HasChanged(void)
	   {Bool_t status=changed;changed=kFALSE;return status;}

	virtual void InitFromEnv(TEnv *env);
	virtual TGCompositeFrame *GetGUI(void);

    ClassDef(FDevice,1)

};

#endif

