// 
// Patron pour la generation d'une classe derivee dans ROOT
// FIPEventReader derive de TNamed
// 
 
#ifndef FIPEventReader_h 
#define FIPEventReader_h 
 
#include "TNamed.h" 
#include "FIPConnection.h" 

#define MAXREADBUFSIZE 32764
#define MAXEVENTMULT 2048
 
class FIPEventReader : public TObject { 
 
   protected:
        UChar_t buf[MAXREADBUFSIZE];
        Bool_t swap;
        Int_t bufSize;
        Int_t index;
        Int_t nbuf;
        Long_t evtNum;
        Short_t mult;
        Short_t label[MAXEVENTMULT];
        Short_t valeur[MAXEVENTMULT];
	
	FIPConnection *sock;
	Bool_t tcp;

   protected: 
        virtual void Init(void);       // initialisation 
	virtual void GetBuffer(void);
        void GetNumber(void *num, Int_t size);
        void SwapNumber(UChar_t *num, Int_t size);
 
   public:
        enum FNetEventReadStatus 
	 {
	 readOk,
	 readError
	 };

   public:	 

   	FIPEventReader(void);    // constructeur par defaut 
	FIPEventReader(const FIPEventReader &ap); // constructeur par copie 
	
	~FIPEventReader(void);		// desctructeur; 
	 
#if ROOT_VERSION_CODE >= ROOT_VERSION(3,4,0)
   	virtual void Copy(TObject & obj) const;
#else
   	virtual void Copy(TObject & obj);
#endif
	FIPEventReader& operator = (const FIPEventReader &hp); // operateur = 

 	virtual void InitSocket(const Char_t *ser=0, 
	                        Int_t port=0, 
				Char_t const *prot="TCP");
	virtual void WaitServerToStart(void);
	virtual void ReleaseSocket(void);
	
	virtual Int_t GetNextEvent(void);
	
	virtual void SetSwap(Bool_t s=kFALSE){swap=s;}
	virtual Bool_t GetSwap(void){return swap;}
	virtual Long_t GetEventNumber(void){return evtNum;}
	virtual Long_t GetNbOfBuffers(void){return nbuf;}
	virtual Short_t GetNbOfParameters(void){return mult;}
	virtual Short_t GetLabel(Int_t i){return label[i];}
	virtual Short_t GetValue(Int_t i){return valeur[i];}
 
    ClassDef(FIPEventReader,1)
 
}; 
 
#endif 
 
