//
// Entete de la classe fenetre secondaire type oscilloscope
//
#ifndef FOscGUI_h
#define FOscGUI_h

#include "TCanvas.h"
#include "TGClient.h"
#include "TGButton.h"
#include "TGTextEntry.h"
#include "TGComboBox.h"
#include "TGColorSelect.h"
#include "TRootEmbeddedCanvas.h"
#include "TGSlider.h"
#include "TGListBox.h"
#include "TGNumberEntry.h"
#include "TSortedList.h"
#include "TFile.h"
#include "TTree.h"
#include "TTimer.h"
#include "TGTab.h"
#include "TGLabel.h"
#include "FEventProcessorThread.h"
#include "MTELabel.h"
#include "MTNELabel.h"
#include "MCBLabel.h"
#include "MEmbeddedCanvasWithMarks.h"
#include "FOscilloH1F.h"

class FOscGUI : public TGMainFrame
{
	private:
	virtual void RestartTimer(void);

	// Declaration des boutons de la fenetre principale
	public:
	TTimer		*displayRefresh;
	TGLabel		*openedConfig;
	TGTextButton	*loadConf;
	TGTextButton 	*openExp;
	MEmbeddedCanvasWithMarks *mecwm;

	TGLayoutHints	*lAffichageB,*lAffichageA,*lAffichageC,*lAffichageF;

	private:
	FEventProcessorThread	*fept;
	TGTextButton *enableSignal1; 
	TGTextButton *enableSignal2; 
	MCBLabel 	*oscilloList1;
	MCBLabel 	*oscilloList2;
	FOscilloH1F *h1;
	FOscilloH1F *h2;
	TGNumberEntry *persistanceEntry1;
	TGNumberEntry *persistanceEntry2;
	TGTextButton *horizontalMode; 
	TGTextButton *verticalMode; 
	TGTextButton *setupMode; 
	Bool_t ch1IsEnabled;
	Bool_t ch2IsEnabled;
	Bool_t horizontalScale;
	Bool_t verticalScale;
	Bool_t modeControl;

	public:
	FOscGUI(const TGWindow *p=0,UInt_t w=1600,UInt_t h=800);
	~FOscGUI();

	virtual FEventProcessorThread *GetFEventProcessorThread(void) { return fept;}
	virtual void SetFEventProcessorThread(FEventProcessorThread *f) { fept=f;}
  	virtual void SetListeOscillos(void);
	virtual void SetConfigName(char *confName);
	virtual void RefreshTrace1(void);
	virtual void RefreshTrace2(void);
	virtual Bool_t HandleTimer(TTimer *timer);
	virtual void RefreshEmbeddedCanvas(void);
	virtual void WarningBox(char const *title="Warning",char const *msg="Warning");
	virtual void GetSignalName1(void);
	virtual void GetSignalName2(void);
	virtual void SetPersistance1(void);
	virtual void SetPersistance2(void);
	virtual void SetHorizontalCursors(void);
	virtual void SetVerticalCursors(void);
	virtual void SetModeControl(void);
	virtual void PrintOscillo(void);
	virtual void SaveOscillos(void);

	ClassDef(FOscGUI,1)
};

#endif
