//
// Patron pour la generation d'une classe derivee dans ROOT
// FOscilloH1F derive de TH1F
//

#ifndef FOscilloH1F_h
#define FOscilloH1F_h

#include "TH1F.h"
#include "FOscilloH1Att.h"

class FOscilloH1F : public TH1F, public FOscilloH1Att {

  protected:
    Double_t  mean;
    Double_t  rms;

    virtual void ComputeMeanRMS(void);

    virtual void Init(void);       // initialisation

  public:
    FOscilloH1F(void);    // constructeur par defaut
    FOscilloH1F(const char* name, const char* title, Int_t nbinsx, Axis_t xlow, Axis_t xup);
    FOscilloH1F(const char* name, const char* title, Int_t nbinsx, const Float_t* xbins);
    FOscilloH1F(const char* name, const char* title, Int_t nbinsx, const Double_t* xbins);
    FOscilloH1F(const FOscilloH1F &ap); // constructeur par copie

    ~FOscilloH1F(void);		// desctructeur;

#if ROOT_VERSION_CODE >= ROOT_VERSION(3,4,0)
    virtual void Copy(TObject & obj) const;
#else
    virtual void Copy(TObject & obj);
#endif
    FOscilloH1F& operator = (const FOscilloH1F &hp); // operateur =

    virtual TH1 *GetHisto(void);
    virtual void SavePrimitive(ostream &out, Option_t *opt="");

    virtual Double_t GetMean(Int_t axis = 1) const;
    virtual Double_t GetRMS(Int_t axis = 1) const;
    
    virtual void ResetAttLine(Option_t *option="");
    virtual void ResetAttMarker(Option_t *option="");

    ClassDef(FOscilloH1F,1)

};

#endif

