// 
// Patron pour la generation d'une classe derivee dans ROOT
// FParamCalc derive de FParamBrut
// 
 
#ifndef FParamCalc_h 
#define FParamCalc_h 
 
#include "FParam.h" 
#include "TFormula.h" 
 
class FParamCalc : public FParam { 
 
   protected:
   	TFormula *formule;
	TList	 *listOfParams;
	Bool_t    computed;
	Double_t  *valuesArray; //!
	Double_t  paramValues[4]; //!
   
   protected: 
        virtual void Init(void);       // initialisation 
        virtual Bool_t CheckNbValues(FParam *p); 
        virtual Int_t ComputeNbValues(Int_t nbv, FParam *p);
 
   public:	 
   	FParamCalc(void);    // constructeur par defaut 
	FParamCalc(const FParamCalc &ap); // constructeur par copie 
	
	~FParamCalc(void);		// desctructeur; 
	 
#if ROOT_VERSION_CODE >= ROOT_VERSION(3,4,0)
   	virtual void Copy(TObject & obj) const;
#else
   	virtual void Copy(TObject & obj);
#endif
	FParamCalc& operator = (const FParamCalc &hp); // operateur = 

	virtual void SetFormula(Char_t *s,Bool_t fatal=kTRUE);
	virtual TString GetFormula(void);
	virtual TFormula *GetTFormula(void) const {return formule;}
	virtual TList *GetListOfParams(void){return listOfParams;}
	virtual void AddParam(FParam *p);
	virtual void AddParamAt(Int_t i,FParam *p);
	virtual void AddParamsFromFormula(Char_t *s,TList *lop);
	virtual void RemoveParams(void);
	virtual void RemoveParamAt(Int_t i);

 	virtual void WriteInFile(ofstream &fout);
 	virtual Bool_t ReadInFile(ifstream &fin,TList *lop);
	
 	virtual void    Reset(void){SetOff();computed=kFALSE;}
	virtual Double_t GetValue(Int_t i=0) const;
        virtual void    SetNbValuesMax(Int_t nbv=1); 
        virtual void    SetNbValues(Int_t nbv=1); 
	virtual Int_t	GetNbValues(void) const;
	virtual Bool_t 	IsOn(void) const;
 	virtual void    SetValue(Double_t val,Int_t i=0);
 
    ClassDef(FParamCalc,1)
 
}; 
 
#endif 
 
