//
// Classe d'affichage des histogrammes pour la manip Fragmentation
//

#ifndef RHV_h
#define RHV_h

#include "TGFrame.h"
#include "TCanvas.h"
#include "TObjArray.h"
#include "TGTab.h"
#include "TGStatusBar.h"
#include "TButton.h"
#include "TTimer.h"
#include "FPageLayout.h"
#include "FBooklet.h"
#include "MCBListManager.h"
#include "RHVOscillo.h"
#include "RHVEditor.h"

class RHV : public TGMainFrame
{
 protected:
  static RHV *currentRHV;
  
  TList  *listOfHistos;
  TList  listOfLayouts;
  TList  listOfBooklets;
  TCanvas *canvasOsc;
  TList listOfCanvases;
  TCanvas *canvasLibre;
  TGStatusBar *statusBar;

  RHVOscillo *oscillo;
  RHVEditor *editor;
 
  TCanvas *currentCanvas;
  TTimer *refreshTimer;
  Long_t canvasRefreshTime;
  FBooklet *currentBooklet;

  TObjArray curBout;
  Pixel_t   boutCol;
  TGTab     *fTab;
  Int_t decTab;
  
  Int_t colTab[2];
  Int_t nTab;
  
  TGLayoutHints *eX;
  TGLayoutHints *eXeY;    
  
  TGCheckButton *curBoutRef;  
  Pixel_t   boutColRefOn;
  Pixel_t   boutColRefOff;
  
  TString	configFile;
  TString	configName;
  TString	mainWindowName;
  
  Bool_t	withEditor;
  Bool_t	withOscillo;
  
  enum 
   {
   loadConfig,
   saveConfig,
   saveConfigAs,
   newBrowser,
   padSaveAs,
   canvasSaveAs,
   padPrint,
   canvasPrint,
   quitRHB
   };
 
 public:
  RHV(const TGWindow *p=0,UInt_t w=800,UInt_t h=600);
  ~RHV();

  static RHV *GetCurrentRHV(void) {return currentRHV;}
  
  virtual void UpdateOscillo(void);
  virtual void SetListOfHistograms(TList *l) 
   {listOfHistos=l;UpdateOscillo();if(editor) editor->SetListOfHistos(l);}
  virtual void AddPageLayout(FPageLayout *pl);
  virtual void AddBooklet(FBooklet *b);
  virtual void LoadConfig(const Char_t *fileName);
  virtual void SaveConfig(const Char_t *fileName);
  virtual const Char_t *GetConfigFileName(void) {return configFile.Data();}
  virtual void DisplayPage(void);
  virtual void HandleFileMenu(Int_t menuItem);
  virtual void HighlightCurrentButton(void);
  virtual void TabSelected(Int_t i);
  virtual void DrawEventStatus(Int_t event, Int_t px, Int_t py, 
               TObject *selected=0);
  virtual void SetNewBooklet(Char_t *blName);
  virtual void RemoveBooklet(Char_t *bName);
  virtual void SetNewPage(Char_t *bName, Char_t *pName);
  virtual void RemovePage(Char_t *bName, Char_t *pName);
  virtual void UpdatePagesButtons(FBooklet *b);
  virtual void ChooseFileToSave(void);
  virtual void ChooseFileToLoad(void);
  virtual void Reset(void);
  virtual void WithEditor(Bool_t we=kFALSE) {withEditor=we;}
  virtual void WithOscillograms(Bool_t wo=kFALSE) {withOscillo=wo;}
  virtual Bool_t HasEditor(void) {return withEditor;}
  virtual Bool_t HasOscillograms(void) {return withOscillo;}
  virtual void AddOscillo(void);
  virtual void AddEditor(void);
  virtual void BuildGUI(void);

  virtual Bool_t      HandleTimer(TTimer *timer);
  virtual void PadRefresh(TPad *pad);
  virtual void RefreshCurrentCanvas(void);
  
  virtual void StopCanvasRefresh(void);
  virtual void DisplayCurrentPage(void);

  virtual void ToggleRefresh(Bool_t ref);
  
  virtual void WarningBox(char const *title="Warning",char const *msg="Warning");
  
ClassDef(RHV,1)
};

#endif
